==> rflowcyt_1.6.0.tar.gz: rflowcyt/man/subset2-methods.Rd <==
\name{"[[-methods"}
\docType{methods}
\alias{"[[-methods"}
\alias{[[-methods}
\alias{"[["-methods}
\alias{"[["}
\alias{[[,ANY-method}
\alias{[[,genericFunction-method}


\title{Extraction of slot information using "[["}
\description{
   Specifically this method is able to extract components or
  slots.
  
  ANY.object[1]  retrieves the first element or slot
  
  FCSmetadata.object["fcsinfo"] obtains the "fcsinfo" slot which is a
  list
  
  FCSmetadata.object["\$P1R"] obtains the first parameter range/max 
  
  FCSmetadata.object[1:10]  obtains first 10 elements of the "fcsinfo"
  slot of the metadata
  
  FCS.object[1,2:3] extracts/reduces the data of the "FCS-class" object
  
}
\section{Methods}{
\describe{

\item{x = "ANY"}{extracts elements}

\item{x = "FCSmetadata"}{Extracts slot information.

  If using a single
  character string index such as the slotNames ("mode" or "\$MODE"; "size" or
  "\$TOT"; "nparam" or "\$PAR"; "longnames" or "\$PnS" or "\$P1S" or "\$P2S"
  etc...; "shortnames"or "\$PnN" or "\$P1N" or "\$P2N" etc...; "paramranges"
  or "\$PnR" or "\$P1R" or "\$P2R" etc...;"fcsinfo";"objectname",
  "original", "filename") as well as the "fcsinfo" slotNames can be
  retrieved.

  If using a numeric single-valued or numeric vector index,
  only the "fcsinfo" slots are numerically indexed and can be retreived. }

\item{x = "FCS"}{extracts the slot information from the metadata portion
  of the object; see x="FCSmetadata" description (above) for specific indexing
  using "[[" }

\item{x="PRIM.step"}{
  extracts the object via a character slot name and/or a numeric
  iteration ID 
  
}

\item{x="PRIM.step.set", y="missing"}{
  extracts the object via a character slot name for the step (ie,
  "peel.step" or "expand.step") and with an optional slot name for the
  "PRIM.step" object.
}

\item{x="PRIM.crossval.step", y="missing"}{
  extracts the object via a character slot name and/or a numeric
  testdata ID}

}}
\keyword{methods}
\keyword{data}

==> rflowcyt_1.22.0.tar.gz: rflowcyt/man/subset2-methods.Rd <==
\name{"[[-methods"}
\docType{methods}
\alias{"[[-methods"}
\alias{[[-method}
\alias{"[["-method}
\alias{"[["}
\alias{"[[",ANY-methods}
\alias{"[[",genericFunction-method}
\alias{[[,FCS,ANY,ANY-method}
\alias{[[<-,FCS,ANY,ANY-method}
\alias{[[,FCSmetadata,ANY,ANY-method}
\alias{[[<-,FCSmetadata,ANY,ANY-method}


\title{Extraction of slot information using "[["}
\description{
   Specifically this method is able to extract components or
  slots.
  
  ANY.object[1]  retrieves the first element or slot
  
  FCSmetadata.object["fcsinfo"] obtains the "fcsinfo" slot which is a
  list
  
  FCSmetadata.object["\$P1R"] obtains the first parameter range/max 
  
  FCSmetadata.object[1:10]  obtains first 10 elements of the "fcsinfo"
  slot of the metadata
  
  FCS.object[1,2:3] extracts/reduces the data of the "FCS-class" object
  
}
\section{Methods}{
\describe{

\item{x = "ANY"}{extracts elements}

\item{x = "FCSmetadata"}{Extracts slot information.

  If using a single
  character string index such as the slotNames ("mode" or "\$MODE"; "size" or
  "\$TOT"; "nparam" or "\$PAR"; "longnames" or "\$PnS" or "\$P1S" or "\$P2S"
  etc...; "shortnames"or "\$PnN" or "\$P1N" or "\$P2N" etc...; "paramranges"
  or "\$PnR" or "\$P1R" or "\$P2R" etc...;"fcsinfo";"objectname",
  "original", "filename") as well as the "fcsinfo" slotNames can be
  retrieved.

  If using a numeric single-valued or numeric vector index,
  only the "fcsinfo" slots are numerically indexed and can be retreived. }

\item{x = "FCS"}{extracts the slot information from the metadata portion
  of the object; see x="FCSmetadata" description (above) for specific indexing
  using "[[" }

\item{x="PRIM.step"}{
  extracts the object via a character slot name and/or a numeric
  iteration ID 
  
}

\item{x="PRIM.step.set", y="missing"}{
  extracts the object via a character slot name for the step (ie,
  "peel.step" or "expand.step") and with an optional slot name for the
  "PRIM.step" object.
}

\item{x="PRIM.crossval.step", y="missing"}{
  extracts the object via a character slot name and/or a numeric
  testdata ID}

}}
\keyword{methods}
\keyword{data}
